@@ -7,14 +7,15 @@
 #'@importFrom rstan traceplot summary
 #'@inheritParams fit_Bayesian_FROC
 #'@inheritParams DrawCurves
+#' @param digits a positive integer, indicating the digit of R hat printed in R/R-studio console
 
 #'@export
 #'@author  \strong{betanalpha}, so not my function. But I modified it. So, alphanbetan is one of the standeveloper, so his function will has consensus, thus I use it.
 
 
 # Checks the potential scale reduction factors
-check_rhat <- function(StanS4class) {
-  message( crayon::silver("\n* One of the Stan developer \"betanalpha\" makes the check_rhat() and it says that "))
+check_rhat <- function(StanS4class, summary=FALSE,digits = 3) {
+  message( crayon::silver("\n* One of the Stan developer \"betanalpha\" made the check_rhat() and it says that "))
 
   fit <-methods::as(StanS4class, "stanfit")
   fit_summary <- summary(fit, probs = c(0.5))$summary
@@ -25,8 +26,10 @@ check_rhat <- function(StanS4class) {
     rhat <- fit_summary[,6][n]
     if (rhat > 1.1 || is.infinite(rhat) || is.nan(rhat)) {
       cat(
-          "\n* Rhat for parameter", rownames(fit_summary)[n], "is", crayon::red$bold$underline$bgWhite(
-rhat ) ,"."
+          "\n* Rhat for parameter",
+          crayon::red$bold$underline$bgWhite( rownames(fit_summary)[n]),
+          "is",
+          crayon::red$bold$underline$bgWhite(   signif(rhat, digits = digits)   ) ,"."
 
         )
       no_warning <- FALSE
@@ -40,4 +43,8 @@ rhat ) ,"."
         '\n* Inequality [ Rhat > 1.1 ] indicates that the chains very likely have not mixed'
         )
       )
+
+
+  if(summary) cat("Max R hat: \n")
+  if(summary) message(  paste( R_hat_max(fit) , crayon::silver(" achieved by the param \"",name_of_param_whose_Rhat_is_maximal(fit), "\"")  ,sep = "")  )
 }
